# Changelog

## Version 0.4.2

* Add provider for Proceedings of Machine Learning Research 
  ([#8](https://github.com/GjjvdBurg/paper2remarkable/issues/8))
* Add provider for NeurIPS papers 
  ([#12](https://github.com/GjjvdBurg/paper2remarkable/issues/12))

## Version 0.4.1

* Add support for alternative arXiv URLS
* Always run all redirects on specified urls before choosing provider

## Version 0.4.0

* Refactor code to make it a real Python package
* Rename to ``paper2remarkable``
